# V1alpha1Arguments

Arguments to a template
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**artifacts** | [**list[V1alpha1Artifact]**](V1alpha1Artifact.md) | Artifacts is the list of artifacts to pass to the template or workflow | [optional] 
**parameters** | [**list[V1alpha1Parameter]**](V1alpha1Parameter.md) | Parameters is the list of parameters to pass to the template or workflow | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


